@@ -1,6 +1,7 @@
 class BridgerFilterMixin:
     def __init__(self, *args, **kwargs):
         self.default = kwargs.pop("default", None)
+        self.required = kwargs.pop("required", False)
         super().__init__(*args, **kwargs)
 
     def get_representation(self, request, name):
@@ -15,8 +16,16 @@ class BridgerFilterMixin:
 
         if self.default:
             if callable(self.default):
-                representation["default"][self.lookup_expr] = self.default(field=self, request=request)
+                representation["default"][self.lookup_expr] = self.default(
+                    field=self, request=request
+                )
             else:
                 representation["default"][self.lookup_expr] = self.default
 
+        if self.required:
+            representation["required"] = True
+            assert (
+                representation["default"] != {}
+            ), "If a filter is required, it needs at least one default value"
+
         return representation
